pub struct RuntimeState {
    pub pos: usize,
}
State of a program runtime

RuntimeState contains information about the current state of a running program. It is used to store information that can be modified during program execution.

Can be used to change execution position at runtime.

Examples

let mut state = RuntimeState::default();

state.pos = 5; // modify current execution position

assert_eq!( state.pos, 5 );

Fields

pos: usize

current execution position that can be changed by user