Module wca::executor::protected

source ·
Protected namespace of the module.

Structs

  • Command Args
  • Container for contexts values
  • Represents a command that can be executed, with a list of command subjects and a set of command options, and a callback function that defines the command logic.
  • Executor that is responsible for executing the program’s commands. It uses the given Context to store and retrieve values during runtime.
  • This is the struct that provides a way to convert a GrammarCommand to an ExecutableCommand.
  • Command Properties
  • Represents the state of the program’s runtime, including the current context, execution position, and namespace of executable commands.
  • State of a program runtime

Enums