Struct wca::ExecutorConverter

source ·
pub struct ExecutorConverter { /* private fields */ }
This is the struct that provides a way to convert a VerifiedCommand to an ExecutableCommand_.

The conversion is done by looking up the Routine associated with the command in a HashMap of routines.

let executor_converter = ExecutorConverter::former()
.routine( "command", Routine::new( |( args, props )| Ok( () ) ) )
.form();

let grammar_command = VerifiedCommand
{
  phrase : "command".to_string(),
  subjects : vec![],
  properties : HashMap::new(),
};

let executable_command = executor_converter.to_command( grammar_command )?;

Implementations

source

impl ExecutorConverter

source

pub fn former() -> ExecutorConverterFormer<ExecutorConverter, ReturnContainer>

Make former, variation of builder pattern to form structure defining values of fields step by step.

source

impl ExecutorConverter

source

pub fn to_program( &self, raw_program: Program<Namespace<VerifiedCommand>> ) -> Result<Program<Namespace<ExecutableCommand_>>>

Converts raw program to executable

source

pub fn to_namespace( &self, raw_namespace: Namespace<VerifiedCommand> ) -> Result<Namespace<ExecutableCommand_>>

Converts raw namespace to executable

source

pub fn to_command(&self, command: VerifiedCommand) -> Result<ExecutableCommand_>

Converts raw command to executable