Struct wca::Program

source ·
pub struct Program<Command> {
    pub commands: Vec<Command>,
}
Represents a program that contains one or more namespaces, where each namespace contains a list of commands.

A Program consists of one or more commannd

The program can be executed by iterating over each commands and executing it

Fields

commands: Vec<Command>

list of namespaces with commands