Struct wca::Verifier

source ·
pub struct Verifier {
    pub commands: HashMap<String, Vec<Command>>,
}
Converts a ParsedCommand to a VerifiedCommand by performing validation and type casting on values.

let grammar = Verifier::former()
.command
(
  Command::former()
  .hint( "hint" )
  .long_hint( "long_hint" )
  .phrase( "command" )
  .form()
)
.form();

let raw_command = ParsedCommand
{
  name: "command".to_string(),
  subjects: vec![],
  properties: HashMap::new(),
};

let grammar_command = grammar.to_command( raw_command )?;

Fields

commands: HashMap<String, Vec<Command>>

all available commands

Implementations

source

impl Verifier

source

pub fn former() -> VerifierFormer<Verifier, ReturnContainer>

Make former, variation of builder pattern to form structure defining values of fields step by step.

source

impl Verifier

source

pub fn to_program( &self, raw_program: Program<Namespace<ParsedCommand>> ) -> Result<Program<Namespace<VerifiedCommand>>>

Converts raw program to grammatically correct

Converts all namespaces into it with to_namespace method.

source

pub fn to_namespace( &self, raw_namespace: Namespace<ParsedCommand> ) -> Result<Namespace<VerifiedCommand>>

Converts raw namespace to grammatically correct

Converts all commands into it with to_command method.

source

pub fn to_command(&self, raw_command: ParsedCommand) -> Result<VerifiedCommand>

Converts raw command to grammatically correct

Make sure that this command is described in the grammar and matches it(command itself and all it options too).