pub struct ExecutableCommand {
pub subjects: Vec<Value>,
pub properties: HashMap<String, Value>,
pub routine: Routine,
}Expand description
Represents a command that can be executed, with a list of command subjects and a set of command options, and a callback function that defines the command logic.
Example:
ExecutableCommand
{
subjects : vec![ Value::String( "subject_value".to_string() ), /* ... */ ],
properties : HashMap::from_iter(
[
( "prop_name".to_string(), Value::Number( 42.0 ) ),
/* ... */
]),
routine : Routine::new( |( args, props )| Ok( () ) )
};Fields
subjects: Vec<Value>subjects values
properties: HashMap<String, Value>properties value
routine: Routinefunction that will be called