This component is responsible for performing
Modules
- Converts from
GrammarCommandtoExecutableCommand - All needed for
ExecutableCommand - Executor that is responsible for executing the program’s commands
- Exposed namespace of the module.
- Orphan namespace of the module.
- Prelude to use essentials:
use my_module::prelude::*. - Protected namespace of the module.
- Represents the state of the program’s runtime
Structs
- Command Args
- Container for contexts values
- Represents a command that can be executed, with a list of command subjects and a set of command options, and a callback function that defines the command logic.
- Executor that is responsible for executing the program’s commands. It uses the given
Contextto store and retrieve values during runtime. - This is the struct that provides a way to convert a
GrammarCommandto anExecutableCommand. - Command Properties
- Represents the state of the program’s runtime, including the current context, execution position, and namespace of executable commands.
- State of a program runtime
Enums
- Represents the type of executor to use for running commands.
- Routine handle.