All needed for ExecutableCommand
Modules
ExecutableCommandrepresentation- Container for contexts values
- Exposed namespace of the module.
- Orphan namespace of the module.
- Prelude to use essentials:
use my_module::prelude::*. - Protected namespace of the module.
- Command callback representation
Structs
- Command Args
- Container for contexts values
- Represents a command that can be executed, with a list of command subjects and a set of command options, and a callback function that defines the command logic.
- Command Properties
Enums
- Routine handle.